#!/bin/bash

# В системе должны быть установлены пакеты
# libxcb-xinerama0, pcscd, libccid, gcr, libpcre16-3

function install_pkg {

    PKG=$1

    PKG_IS_INSTALLED=`dpkg -s $PKG 2>/dev/null | grep "Status: install ok installed"`
    if [ -z "$PKG_IS_INSTALLED" ]; then
        echo "Не установлен пакет $PKG!"
        echo "Будет выполнена попытка его установки."
        echo "В процессе установки на предложение системы установите"
        echo "необходимый диск с дистрибутивом ОС в CD-ROM."
        echo "Для продолжения нажмите клавишу ВВОД..."
        read
        sudo apt-get install -y $PKG
    fi

    PKG_IS_INSTALLED=`dpkg -s $PKG 2>/dev/null | grep "Status: install ok installed"`
    if [ -z "$PKG_IS_INSTALLED" ]; then
        echo "Не удалось установить пакет $PKG!"
        echo "Установите пакет вручную и запустите установочный скрипт заново!"
        exit 1
    fi

}

install_pkg pcscd
install_pkg gcr
install_pkg libpcre16-3
install_pkg libxcb-xinerama0

JCPKCS_PACKAGE=`ls -l "$(dirname "$0")" | sed -r -n 's/.*(jcpkcs11-2_[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+_al_x64\.deb)/\1/p'`
UC_PACKAGE=`ls -l "$(dirname "$0")" | sed -r -n 's/.*(jacartauc_[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+_al_x64\.deb)/\1/p'`
JCSECURBIO_PACKAGE=`ls -l "$(dirname "$0")" | sed -r -n 's/.*(jcsecurbio_[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+_x64\.deb)/\1/p'`
cd "$(dirname "$0")"

if [ -z "AO_Aladdin_public.key" ]; then
    echo "Ошибка!!! Отсутствует публичный ключ АО \"Аладдин Р.Д.\"!"
    exit 1
fi

if [ -z "$JCPKCS_PACKAGE" ]; then
    echo "Ошибка!!! Отсутствует пакет jcpkcs11-2!"
    exit 1
fi

if [ -z "$UC_PACKAGE" ]; then
    echo "Ошибка!!! Отсутствует пакет jacartauc!"
    exit 1
fi

sudo cp AO_Aladdin_public.key "/etc/digsig/keys/" 

echo "Устанавливается пакет jcpkcs11-2!"
echo "=========================================="
sudo dpkg -i $JCPKCS_PACKAGE

echo
echo "Устанавливается пакет jacartauc!"
echo "=========================================="
sudo dpkg -i $UC_PACKAGE

echo
echo "Устанавливается пакет jcsecurbio!"
echo "=========================================="
sudo dpkg -i $JCSECURBIO_PACKAGE

#далее обрабатываются допустимые флаги установки
conf_file=/etc/xdg/AladdinRD/JCUC.conf
if [[ ! -f "$conf_file" && $# -gt 0 ]]; then
    sudo mkdir -p $(dirname "$conf_file")
    sudo sh -c "echo '[General]' > $conf_file"
fi

for i in "$@"; do
  case $i in
    --sys_tray_icon_visible=*)
      SYS_TRAY="${i#*=}"
      shift
      if [[ "$SYS_TRAY" == "no" ]]; then
        SYS_TRAY="sys-tray-icon-visible=false"
      elif [[ "$SYS_TRAY" == "yes" ]]; then
        SYS_TRAY="sys-tray-icon-visible=true"
      else
        SYS_TRAY=""
      fi
      if [[ -f "$conf_file" && $SYS_TRAY ]]; then 
        line_number=$(grep -n "sys-tray-icon-visible" "$conf_file" | head -1 | cut -d':' -f1)
        if [[ $line_number > 0 ]]; then
          sudo sed -i "${line_number}s/.*/$SYS_TRAY/" "$conf_file"
        else
          line_number_general=$(grep -n '[General]' "$conf_file" | head -1 | cut -d':' -f1)
          if [[ $line_number_general > 0 ]]; then
            sudo sed -i "${line_number_general}a ${SYS_TRAY}" "$conf_file"
          else
            sudo sed -i '1i\'"$SYS_TRAY" "$conf_file"
          fi
        fi
      fi
      ;;
    --number_days_to_pin_expire=*)
      NUM_DAYS="${i#*=}"
      shift
      if [ -f "$conf_file" ] && [[ $NUM_DAYS =~ ^[0-9]+$ ]] && [[ $NUM_DAYS -ge 0 && $NUM_DAYS -le 365 ]]; then
        line_number=$(grep -n "number-days-to-pin-expire" "$conf_file" | head -1 | cut -d':' -f1)
        if [[ $line_number > 0 ]]; then
          sudo sed -i "${line_number}s/.*/number-days-to-pin-expire=$NUM_DAYS/" "$conf_file"
        else
          line_number_general=$(grep -n '[General]' "$conf_file" | head -1 | cut -d':' -f1)
          if [[ $line_number_general > 0 ]]; then
            sudo sed -i "${line_number_general}a number-days-to-pin-expire=$NUM_DAYS" "$conf_file"
          else
            sudo sed -i '1i\'"number-days-to-pin-expire=$NUM_DAYS" "$conf_file"
          fi
        fi
      fi
      ;;
    --certs_expiring_warning_visible=*)
      CERTS_EXPIRING="${i#*=}"
      shift
      if [[ "$CERTS_EXPIRING" == "no" ]]; then
        CERTS_EXPIRING="certs-expiring-warning-visible=false"
      elif [[ "$CERTS_EXPIRING" == "yes" ]]; then
        CERTS_EXPIRING="certs-expiring-warning-visible=true"
      else
        CERTS_EXPIRING=""
      fi
      if [[ -f "$conf_file" && $CERTS_EXPIRING ]]; then
        line_number=$(grep -n "certs-expiring-warning-visible" "$conf_file" | head -1 | cut -d':' -f1)
        if [[ $line_number > 0 ]]; then
          sudo sed -i "${line_number}s/.*/$CERTS_EXPIRING/" "$conf_file"
        else 
          line_number_general=$(grep -n '[General]' "$conf_file" | head -1 | cut -d':' -f1)
          if [[ $line_number_general > 0 ]]; then
            sudo sed -i "${line_number_general}a ${CERTS_EXPIRING}" "$conf_file"
          else
            sudo sed -i '1i\'"$CERTS_EXPIRING" "$conf_file"
          fi
        fi
      fi
      ;;
    --certs_expired_warning_visible=*)
      CERTS_EXPIRED="${i#*=}"
      shift
      if [[ "$CERTS_EXPIRED" == "no" ]]; then
        CERTS_EXPIRED="certs-expired-warning-visible=false"
      elif [[ "$CERTS_EXPIRED" == "yes" ]]; then
        CERTS_EXPIRED="certs-expired-warning-visible=true"
      else
        CERTS_EXPIRED=""
      fi
      if [[ -f "$conf_file" && $CERTS_EXPIRED ]]; then
        line_number=$(grep -n "certs-expired-warning-visible" "$conf_file" | head -1 | cut -d':' -f1)
        if [[ $line_number > 0 ]]; then
          sudo sed -i "${line_number}s/.*/$CERTS_EXPIRED/" "$conf_file"
        else 
          line_number_general=$(grep -n '[General]' "$conf_file" | head -1 | cut -d':' -f1)
          if [[ $line_number_general > 0 ]]; then
            sudo sed -i "${line_number_general}a ${CERTS_EXPIRED}" "$conf_file"
          else
            sudo sed -i '1i\'"$CERTS_EXPIRED" "$conf_file"
          fi
        fi 
      fi
      ;;
    --pin_expiration_as_dialog=*)
      PIN_DIALOG="${i#*=}"
      shift
      if [[ "$PIN_DIALOG" == "no" ]]; then
        PIN_DIALOG="pin-expiration-warning-display-as-dialog=false"
      elif [[ "$PIN_DIALOG" == "yes" ]]; then
        PIN_DIALOG="pin-expiration-warning-display-as-dialog=true"
      else
        PIN_DIALOG=""
      fi
      if [[ -f "$conf_file" && $PIN_DIALOG ]]; then
        line_number=$(grep -n "pin-expiration-warning-display-as-dialog" "$conf_file" | head -1 | cut -d':' -f1)
        if [[ $line_number > 0 ]]; then
          sudo sed -i "${line_number}s/.*/$PIN_DIALOG/" "$conf_file"
        else
          line_number_general=$(grep -n '[General]' "$conf_file" | head -1 | cut -d':' -f1)
          if [[ $line_number_general > 0 ]]; then
            sudo sed -i "${line_number_general}a ${PIN_DIALOG}" "$conf_file"
          else
            sudo sed -i '1i\'"$PIN_DIALOG" "$conf_file"
          fi
        fi
      fi 
      ;;
  esac
done